[gparted] Rename Partition Label to File System Label in the GUI (#741424)



commit 332a2e7a79048b06bedb707d40d98e5f44d3f5e0
Author: Mike Fleetwood <mike fleetwood googlemail com>
Date:   Mon Dec 15 23:20:12 2014 +0000

    Rename Partition Label to File System Label in the GUI (#741424)
    
    Rename the Partition Label concept to File System Label throughout the
    GUI.  This is to better reflect that it is the label of the file system
    that is being modified and to separate it from the Partition Name
    concept about to be added.
    
    Bug 741424 - Add support for GPT partition names

 src/Dialog_Partition_Label.cc  |    4 ++--
 src/GParted_Core.cc            |   13 +++++--------
 src/OperationLabelPartition.cc |   14 +++++++-------
 src/Win_GParted.cc             |    2 +-
 4 files changed, 15 insertions(+), 18 deletions(-)
---
diff --git a/src/GParted_Core.cc b/src/GParted_Core.cc
index 3477460..413a887 100644
--- a/src/GParted_Core.cc
+++ b/src/GParted_Core.cc
@@ -2072,15 +2072,12 @@ bool GParted_Core::remove_filesystem( const Partition & partition, OperationDeta
 bool GParted_Core::label_partition( const Partition & partition, OperationDetail & operationdetail )   
 {
        if( partition .get_label() .empty() ) {
-               operationdetail .add_child( OperationDetail( String::ucompose(
-                                                                                                             
  _("Clear partition label on %1"),
-                                                                                                             
  partition .get_path()
-                                                                                                        ) ) 
) ;
+               operationdetail.add_child( OperationDetail(
+                       String::ucompose( _("Clear file system label on %1"), partition.get_path() ) ) );
        } else {
-               operationdetail .add_child( OperationDetail( String::ucompose(
-                                                                                                             
  _("Set partition label to \"%1\" on %2"),
-                                                                                                             
  partition .get_label(), partition .get_path()
-                                                                                                        ) ) 
) ;
+               operationdetail.add_child( OperationDetail(
+                       String::ucompose( _("Set file system label to \"%1\" on %2"),
+                                         partition.get_label(), partition.get_path() ) ) );
        }
 
        bool succes = false ;
diff --git a/src/Win_GParted.cc b/src/Win_GParted.cc
index 5e60306..4534f13 100644
--- a/src/Win_GParted.cc
+++ b/src/Win_GParted.cc
@@ -388,7 +388,7 @@ void Win_GParted::init_partition_menu()
        MENU_CHECK = index++ ;
 
        menu_partition .items() .push_back(
-                       Gtk::Menu_Helpers::MenuElem( _("_Label"),
+                       Gtk::Menu_Helpers::MenuElem( _("_Label File System"),
                                                     sigc::mem_fun( *this, 
&Win_GParted::activate_label_partition ) ) );
        MENU_LABEL_PARTITION = index++ ;
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/Dialog_Partition_Label.cc b/src/Dialog_Partition_Label.cc
index 2a39d8d..80b20cd 100644
--- a/src/Dialog_Partition_Label.cc
+++ b/src/Dialog_Partition_Label.cc
@@ -25,8 +25,8 @@ Dialog_Partition_Label::Dialog_Partition_Label( const Partition & partition )
        this ->set_has_separator( false ) ;
        this ->set_size_request( 300, 80 ) ;
        
-       /*TO TRANSLATORS: dialog title, looks like Set partition label on /dev/hda3 */
-       this ->set_title( String::ucompose( _("Set partition label on %1"), partition .get_path() ) );
+       /* TO TRANSLATORS: dialog title, looks like   Set file system label on /dev/hda3 */
+       this->set_title( String::ucompose( _("Set file system label on %1"), partition.get_path() ) );
 
        {
                int top = 0, bottom = 1;
diff --git a/src/OperationLabelPartition.cc b/src/OperationLabelPartition.cc
index ce1ae3e..4403ea8 100644
--- a/src/OperationLabelPartition.cc
+++ b/src/OperationLabelPartition.cc
@@ -54,14 +54,14 @@ void OperationLabelPartition::apply_to_visual( std::vector<Partition> & partitio
 void OperationLabelPartition::create_description() 
 {
        if( partition_new .get_label() .empty() ) {
-               /*TO TRANSLATORS: looks like   Clear Partition Label on /dev/hda3 */
-               description = String::ucompose( _("Clear Partition Label on %1"),
-                                               partition_new .get_path() ) ;
+               /* TO TRANSLATORS: looks like   Clear file system Label on /dev/hda3 */
+               description = String::ucompose( _("Clear file system label on %1"),
+                                               partition_new.get_path() );
        } else {
-               /*TO TRANSLATORS: looks like   Set Partition Label "My Label" on /dev/hda3 */
-               description = String::ucompose( _("Set Partition Label \"%1\" on %2"),
-                                               partition_new .get_label(),
-                                               partition_new .get_path() ) ;
+               /* TO TRANSLATORS: looks like   Set file system label "My Label" on /dev/hda3 */
+               description = String::ucompose( _("Set file system label \"%1\" on %2"),
+                                               partition_new.get_label(),
+                                               partition_new.get_path() );
        }
 }
 